@@ -7,15 +7,15 @@ use Test::More qw();
 use Scalar::Util qw(blessed);
 use Types::TypeTiny qw(to_TypeTiny);
 
-require Exporter::TypeTiny;
-our @ISA = 'Exporter::TypeTiny';
+require Exporter::Tiny;
+our @ISA = 'Exporter::Tiny';
 
 BEGIN {
 	*EXTENDED_TESTING = $ENV{EXTENDED_TESTING} ? sub(){!!1} : sub(){!!0};
 };
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.027_09';
+our $VERSION   = '0.029_01';
 our @EXPORT    = qw( should_pass should_fail ok_subtype );
 our @EXPORT_OK = qw( EXTENDED_TESTING );
 
